# aws_pcluster_bootstrap_helpers

[![image](https://img.shields.io/pypi/v/aws_pcluster_bootstrap_helpers.svg)](https://pypi.python.org/pypi/aws_pcluster_bootstrap_helpers)

[![image](https://img.shields.io/travis/dabble-of-devops-bioanalyze/aws_pcluster_bootstrap_helpers.svg)](https://travis-ci.com/dabble-of-devops-bioanalyze/aws_pcluster_bootstrap_helpers)

Helpers to bootstrap a AWS PCluster + SLURM + Custom AMIs

- Free software: Apache Software License 2.0

## Features

- Build a PCluster AMI and watch it
- Build a PCluster Cluster

Please note that you must build new AMIs per version of parallel cluster and region.

## Credits

This package was created with
[Cookiecutter](https://github.com/audreyr/cookiecutter) and the
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
project template.
